@@ -1,8 +1,9 @@
 from ixnetwork_restpy.testplatform.testplatform import TestPlatform
 from ixnetwork_restpy.files import Files
+from ixnetwork_restpy.errors import *
 try:
     from ixnetwork_restpy.assistants.statistics.statviewassistant import StatViewAssistant
     from ixnetwork_restpy.assistants.ports.portmapassistant import PortMapAssistant
     from ixnetwork_restpy.assistants.sessions.sessionassistant import SessionAssistant
-except Exception as e:
-    print('non-generated class usage for generator build...')
\ No newline at end of file
+except:
+    pass
