@@ -1,14 +1,14 @@
 """ Assistant class to simplify access to statistics views
 """
-
 from ixnetwork_restpy.assistants.statistics.row import Row
-from ixnetwork_restpy.testplatform.sessions.ixnetwork.ixnetwork import Ixnetwork
 from ixnetwork_restpy.errors import *
 from ixnetwork_restpy.files import Files
 import re
 import os
+import io
 import time
 
+
 try:
     basestring
 except NameError:
@@ -22,27 +22,35 @@ class StatViewAssistant(object):
     NOT_EQUAL = '!='
     GREATER_THAN = '>'
     GREATER_THAN_OR_EQUAL = '>='
+    TABLE = 1
+    OBJECT = 2
 
     @staticmethod
     def GetViewNames(IxNetwork):
         """Get a list of all view names.
         """
-        assert(isinstance(IxNetwork, Ixnetwork))
         view_names = []
         for view in IxNetwork.Statistics.View.find():
             view_names.append(view.Caption)
         return view_names
 
-    def __init__(self, IxNetwork, ViewName, Timeout=180, LocalCsvStorage=None):
+    def __init__(self, IxNetwork, ViewName, Timeout=180, LocalCsvStorage=None, 
+        PrintFormat=OBJECT, PrintColumns=[]):
         """
         Args
         ----
         - IxNetwork (obj (ixnetwork_restpy.testplatform.sessions.ixnetwork.Ixnetwork)): An Ixnetwork object
         - ViewName (str): The name of a statistics view, supports regex
         - Timeout (int): The timeout in seconds to wait for the ViewName to be available and/or ready
-        - LocalCsvStorage (str): The local path where downloaded csv statistic files will be stored. The path must exist and will not be created.
+        - LocalCsvStorage (str): The local path where downloaded csv statistic files will be stored. 
+            The path must exist and will not be created.
+        - PrintFormat (str(StatViewAssistant.OBJECT | StatViewAssistant.TABLE)): formatting for __str__
+            If PrintFormat is OBJECT each row will be output as lines of colname: colvalue
+            If PrintFormat is TABLE each row will be output as a single line
+        - PrintColumns (list(str)): A list of statistic column names that will be printed out
+            If the list is None all columns will be printed out
         """
-        assert(isinstance(IxNetwork, Ixnetwork))
+        self._snapshot = None
         self._IxNetwork = IxNetwork
         self._ViewName = ViewName
         self._root_directory = self._IxNetwork._connection._read('%s/files' % self._IxNetwork.href)['absolute']
@@ -50,19 +58,28 @@ class StatViewAssistant(object):
         self._View = None
         self._Timeout = Timeout
         self._LocalCsvStorage = LocalCsvStorage
+        self._PrintFormat = PrintFormat
+        self._PrintColumns = PrintColumns
         self.ClearRowFilters()
         self._is_view_ready
 
     def _take_csv_snapshot(self):
-        self._Statistics.CsvSnapshot.CsvStringQuotes = False
-        self._Statistics.CsvSnapshot.SnapshotViewContents = 'allPages'
-        self._Statistics.CsvSnapshot.SnapshotViewCsvGenerationMode = 'overwriteCSVFile'
-        self._Statistics.CsvSnapshot.CsvLocation = self._root_directory
         csv_name = re.sub("[^A-Za-z0-9]+", "-", self._View.Caption)
-        self._Statistics.CsvSnapshot.CsvName = 'ixnetwork.restpy.%s' % csv_name
-        self._Statistics.CsvSnapshot.Views = self._View
-        self._Statistics.CsvSnapshot.TakeCsvSnapshot()
-        return self._IxNetwork._connection._get_file(self._IxNetwork.href, '%s.csv' % self._Statistics.CsvSnapshot.CsvName, local_directory=self._LocalCsvStorage)
+        snapshot_name = 'ixnetwork.restpy.%s.%s' % (time.time(), csv_name)
+        csv_snapshot = self._Statistics.CsvSnapshot
+        csv_snapshot.update(CsvStringQuotes = False,
+            SnapshotViewContents = 'allPages',
+            SnapshotViewCsvGenerationMode = 'overwriteCSVFile',
+            CsvLocation = self._root_directory,
+            CsvName = snapshot_name,
+            Views = self._View)
+        csv_snapshot.TakeCsvSnapshot()
+        self._snapshot = io.BytesIO(self._IxNetwork._connection._get_file(self._IxNetwork.href, 
+            '%s.csv' % snapshot_name, return_content=True))
+        self._IxNetwork._connection._delete_file(self._IxNetwork.href, 
+            '%s.csv' % snapshot_name)
+        self._IxNetwork._connection._delete_file(self._IxNetwork.href, 
+            '%s.csv.columns' % snapshot_name)
 
     @property
     def _is_view_ready(self):
@@ -91,37 +108,39 @@ class StatViewAssistant(object):
             obj (ixnetwork_restpy.assistants.statistics.row.Row): An iterable class encapsulating row data
         """
         self._is_view_ready
-        local_filename = self._take_csv_snapshot()
+        self._take_csv_snapshot()
         rows = []
-        column_headers = []
-        with open(local_filename, 'r') as fid:
-            column_headers = fid.readline()[:-1].split(',')
-            for row in fid:
-                row = row[:-1]
-                row = ''.join(x if i % 2 == 0 else x.replace(',', ' ')
-                    for i, x in enumerate(row.split('"')))
-                row = row.split(',')
-                match = True
-                for column_index in range(len(row)):
-                    if column_index in self._filters.keys():
-                        for column_filter in self._filters[column_index]:
-                            comparator = column_filter['comparator']
-                            filter_value = column_filter['filterValue']
-                            if comparator == StatViewAssistant.REGEX:
-                                if filter_value.search(row[column_index]) is None:
+        column_headers = self._snapshot.readline()
+        if isinstance(column_headers, bytes) is True:
+            column_headers = column_headers.decode('ascii')
+        column_headers = column_headers.rstrip().split(',')
+        for row in self._snapshot:
+            if isinstance(row, bytes) is True:
+                row = row.decode('ascii')
+            row = row.rstrip()
+            row = ''.join(x if i % 2 == 0 else x.replace(',', ' ')
+                for i, x in enumerate(row.split('"')))
+            row = row.split(',')
+            match = True
+            for column_index in range(len(row)):
+                if column_index in self._filters.keys():
+                    for column_filter in self._filters[column_index]:
+                        comparator = column_filter['comparator']
+                        filter_value = column_filter['filterValue']
+                        if comparator == StatViewAssistant.REGEX:
+                            if filter_value.search(row[column_index]) is None:
+                                match = False
+                                break
+                        else:
+                            try:
+                                expression = '"%s" %s "%s"' % (row[column_index], comparator, filter_value)
+                                if eval(expression) is False:
                                     match = False
                                     break
-                            else:
-                                try:
-                                    expression = '"%s" %s "%s"' % (row[column_index], comparator, filter_value)
-                                    if eval(expression) is False:
-                                        match = False
-                                        break
-                                except Exception as e:
-                                    self._IxNetwork.debug('%s Rows eval of %s failed: %s' % (__file__, expression, e))
-                if match is True:
-                    rows.append(row)
-        os.remove(local_filename)
+                            except Exception as e:
+                                self._IxNetwork.debug('%s Rows eval of %s failed: %s' % (__file__, expression, e))
+            if match is True:
+                rows.append(row)
         return Row(self._View.Caption, column_headers, rows)
 
     @property
@@ -188,7 +207,10 @@ class StatViewAssistant(object):
                     match = re.match(ConditionValue, row[ColumnName])
                 else:
                     expression = '%s %s %s' % (row[ColumnName], Comparator, ConditionValue)
-                    match = eval(expression)
+                    try:
+                        match = eval(expression)
+                    except:
+                        match = False
                 if match is None or match is False:
                     break
             if match is None or match is False:
@@ -248,6 +270,21 @@ class StatViewAssistant(object):
         """Return a string with all the rows in the current view
         """
         statistics = ''
-        for row in self.Rows:
-            statistics += row.__str__()
-        return statistics
+        column_headers = self.ColumnHeaders
+        if self._PrintFormat == StatViewAssistant.TABLE:
+            table_row = '|'
+            for i in range(0, len(column_headers)):
+                if len(self._PrintColumns) == 0 or column_headers[i] in self._PrintColumns:
+                    table_row += column_headers[i].ljust(18) + '|'
+            statistics += table_row + '\n'
+            statistics += '-' * len(table_row) + '\n'
+            for line in self.Rows.RawData:
+                table_row = '|'
+                for i in range(0, len(line)):
+                    if len(self._PrintColumns) == 0 or column_headers[i] in self._PrintColumns:
+                        table_row += line[i].ljust(18) + '|'
+                statistics += table_row + '\n'
+        else:
+            for row in self.Rows:
+                statistics += row.__str__()
+        return statistics.rstrip()
