@@ -6,31 +6,31 @@ The sample operates under the following assumptions:
     - there is a Flow Statistics view
 
 """
-import os
 from ixnetwork_restpy import SessionAssistant
-
+import os
 
 session_assistant = SessionAssistant(IpAddress='127.0.0.1', 
     UserName='admin', Password='admin',
-    LogLevel=SessionAssistant.LOGLEVEL_INFO, 
-    ClearConfig=True)
+    LogLevel=SessionAssistant.LOGLEVEL_INFO)
 ixnetwork = session_assistant.Ixnetwork
-
+session = session_assistant.Session
 
 ixnetwork.info('''
 1) setup the csv snapshot parameters
-2) ensure the CsvName ends with the .csv extension
-    if it does not the IxNetwork server will add the .csv extension to the final csv filename
+2) ensure the CsvName DOES NOT end with a .csv extension
+	the IxNetwork server will add a .csv extension to the final csv filename
 3) ensure the CsvLocation is a path on the IxNetwork server that the IxNetwork server has access to, 
-    the best practice is to use the Ixnetwork.Statistics.CsvFilePath location
+	the best practice is to use the Ixnetwork.Statistics.CsvFilePath location
 ''')
 statistics = ixnetwork.Statistics
 csvsnapshot = statistics.CsvSnapshot
-csvsnapshot.update(CsvName="Flow Statistics Snapshot.csv",
-    CsvLocation=statistics.CsvFilePath,
+csvsnapshot.update(CsvName="StatisticsSnapshot",
+	CsvLocation=statistics.CsvFilePath,
     SnapshotViewCsvGenerationMode='overwriteCSVFile',
     SnapshotViewContents='allPages',
-    Views=statistics.View.find(Caption='Flow Statistics'))
+    Views=statistics.View.find(Caption='Port Statistics'))
+
+ixnetwork.info(csvsnapshot)
 
 ixnetwork.info('''
 4) take the csv snapshot
@@ -39,8 +39,14 @@ csvsnapshot.TakeCsvSnapshot()
 
 ixnetwork.info('''
 5) the csv snapshot file is on the IxNetwork server and can be downloaded
-    the csv snapshot file name is the CsvLocation and CsvName
+	The csv snapshot file name is the CsvLocation and CsvName and .csv extension
+    The snapshot API will always add a .csv extension
 ''')
-remote_filename = os.path.join(csvsnapshot.CsvLocation, csvsnapshot.CsvName)
-local_filename = os.path.join('c:/temp', csvsnapshot.CsvName)
-session_assistant.Session.DownloadFile(remote_filename, local_filename)
\ No newline at end of file
+file_name = csvsnapshot.CsvName + '.csv'
+remote_filename = os.path.normpath(os.path.join(csvsnapshot.CsvLocation, file_name))
+local_filename = os.path.normpath(os.path.join('c:/temp', file_name))
+session.DownloadFile(remote_filename, local_filename)
+
+with open(local_filename, 'r') as fid:
+    print(fid.read())
+
