@@ -1,6 +1,6 @@
 # MIT LICENSE
 #
-# Copyright 1997 - 2019 by IXIA Keysight
+# Copyright 1997 - 2020 by IXIA Keysight
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"),
@@ -30,6 +30,8 @@ class Ixreporter(Base):
 
     __slots__ = ()
     _SDM_NAME = 'ixreporter'
+    _SDM_ATT_MAP = {
+    }
 
     def __init__(self, parent):
         super(Ixreporter, self).__init__(parent)
