@@ -1,6 +1,6 @@
 # MIT LICENSE
 #
-# Copyright 1997 - 2019 by IXIA Keysight
+# Copyright 1997 - 2020 by IXIA Keysight
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"),
@@ -170,6 +170,19 @@ class IsisDcePseudoIfaceAttPoint1Config(Base):
         """
         return self._get_ngpf_device_ids(locals())
 
+    def Abort(self):
+        """Executes the abort operation on the server.
+
+        Abort CPF control plane (equals to demote to kUnconfigured state).
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        payload = { "Arg1": self }
+        return self._execute('abort', payload=payload, response_object=None)
+
     def Disconnect(self, *args, **kwargs):
         """Executes the disconnect operation on the server.
 
@@ -179,7 +192,7 @@ class IsisDcePseudoIfaceAttPoint1Config(Base):
 
         disconnect(SessionIndices=list)
         -------------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         disconnect(SessionIndices=string)
         ---------------------------------
@@ -204,7 +217,7 @@ class IsisDcePseudoIfaceAttPoint1Config(Base):
 
         reconnect(SessionIndices=list)
         ------------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         reconnect(SessionIndices=string)
         --------------------------------
