@@ -1,6 +1,6 @@
 # MIT LICENSE
 #
-# Copyright 1997 - 2019 by IXIA Keysight
+# Copyright 1997 - 2020 by IXIA Keysight
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"),
@@ -734,6 +734,31 @@ class LdpTargetedRouterV6(Base):
         """
         return self._get_ngpf_device_ids(locals())
 
+    def Abort(self, *args, **kwargs):
+        """Executes the abort operation on the server.
+
+        Abort CPF control plane (equals to demote to kUnconfigured state).
+
+        The IxNetwork model allows for multiple method Signatures with the same name while python does not.
+
+        abort(SessionIndices=list)
+        --------------------------
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
+
+        abort(SessionIndices=string)
+        ----------------------------
+        - SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12
+
+        Raises
+        ------
+        - NotFoundError: The requested resource does not exist on the server
+        - ServerError: The server has encountered an uncategorized error condition
+        """
+        payload = { "Arg1": self }
+        for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
+        for item in kwargs.items(): payload[item[0]] = item[1]
+        return self._execute('abort', payload=payload, response_object=None)
+
     def ClearAllLearnedInfo(self, *args, **kwargs):
         """Executes the clearAllLearnedInfo operation on the server.
 
@@ -743,7 +768,7 @@ class LdpTargetedRouterV6(Base):
 
         clearAllLearnedInfo(SessionIndices=list)
         ----------------------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         clearAllLearnedInfo(SessionIndices=string)
         ------------------------------------------
@@ -788,7 +813,7 @@ class LdpTargetedRouterV6(Base):
 
         getAllLearnedInfo(SessionIndices=list)
         --------------------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         getAllLearnedInfo(SessionIndices=string)
         ----------------------------------------
@@ -818,7 +843,7 @@ class LdpTargetedRouterV6(Base):
 
         getFEC128LearnedInfo(SessionIndices=list)
         -----------------------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         getFEC128LearnedInfo(SessionIndices=string)
         -------------------------------------------
@@ -848,7 +873,7 @@ class LdpTargetedRouterV6(Base):
 
         getFEC129LearnedInfo(SessionIndices=list)
         -----------------------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         getFEC129LearnedInfo(SessionIndices=string)
         -------------------------------------------
@@ -878,7 +903,7 @@ class LdpTargetedRouterV6(Base):
 
         getIPv4FECLearnedInfo(SessionIndices=list)
         ------------------------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         getIPv4FECLearnedInfo(SessionIndices=string)
         --------------------------------------------
@@ -908,7 +933,7 @@ class LdpTargetedRouterV6(Base):
 
         getIPv6FECLearnedInfo(SessionIndices=list)
         ------------------------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         getIPv6FECLearnedInfo(SessionIndices=string)
         --------------------------------------------
@@ -938,7 +963,7 @@ class LdpTargetedRouterV6(Base):
 
         getP2MPFECLearnedInfo(SessionIndices=list)
         ------------------------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         getP2MPFECLearnedInfo(SessionIndices=string)
         --------------------------------------------
@@ -973,7 +998,7 @@ class LdpTargetedRouterV6(Base):
         gracefullyRestart(Delay=number, SessionIndices=list)
         ----------------------------------------------------
         - Delay (number): This parameter requires a delay of type kInteger
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         gracefullyRestart(SessionIndices=string, Delay=number)
         ------------------------------------------------------
@@ -1005,7 +1030,7 @@ class LdpTargetedRouterV6(Base):
 
         restartDown(SessionIndices=list)
         --------------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         restartDown(SessionIndices=string)
         ----------------------------------
@@ -1030,7 +1055,7 @@ class LdpTargetedRouterV6(Base):
 
         resumeKeepAlive(SessionIndices=list)
         ------------------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         resumeKeepAlive(SessionIndices=string)
         --------------------------------------
@@ -1069,13 +1094,13 @@ class LdpTargetedRouterV6(Base):
     def Start(self, *args, **kwargs):
         """Executes the start operation on the server.
 
-        Start LDP Router
+        Start CPF control plane (equals to promote to negotiated state).
 
         The IxNetwork model allows for multiple method Signatures with the same name while python does not.
 
         start(SessionIndices=list)
         --------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         start(SessionIndices=string)
         ----------------------------
@@ -1094,13 +1119,13 @@ class LdpTargetedRouterV6(Base):
     def Stop(self, *args, **kwargs):
         """Executes the stop operation on the server.
 
-        Stop LDP Router
+        Stop CPF control plane (equals to demote to PreValidated-DoDDone state).
 
         The IxNetwork model allows for multiple method Signatures with the same name while python does not.
 
         stop(SessionIndices=list)
         -------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         stop(SessionIndices=string)
         ---------------------------
@@ -1125,7 +1150,7 @@ class LdpTargetedRouterV6(Base):
 
         stopKeepAlive(SessionIndices=list)
         ----------------------------------
-        - SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3
+        - SessionIndices (list(number)): This parameter requires an array of session numbers 1 2 3
 
         stopKeepAlive(SessionIndices=string)
         ------------------------------------
